# Display mode
class Mode:
    DEFAULT = 0
    BOLD = 1
    UNDER_LINE = 4
    FLASH = 5
    REVERSE = 7


class Fore:
    DEFAULT = -1
    BLACK = 30
    RED = 31
    GREEN = 32
    YELLOW = 33
    BLUE = 34
    MAGENTA = 35
    CYAN = 36
    WHITE = 37


class Back:
    DEFAULT = -1
    BLACK = 40
    RED = 41
    GREEN = 42
    YELLOW = 43
    BLUE = 44
    MAGENTA = 45
    CYAN = 46
    WHITE = 47
